@@ -70,19 +70,19 @@ class thdate {
 
   public:
 
-  int syear,  ///< Start date year
-    smonth,  ///< Start date month
-    sday,  ///< Start date day
-    shour,  ///< Star date hour
-    smin,  ///< Star date minute
-    eyear,  ///< End date year
-    emonth,  ///< End date month
-    eday,  ///< End date month
-    ehour,  ///< End date hour
-    emin;  ///< End date minute
+  int syear = -1,  ///< Start date year
+    smonth = -1,  ///< Start date month
+    sday = -1,  ///< Start date day
+    shour = -1,  ///< Star date hour
+    smin = -1,  ///< Star date minute
+    eyear = -1,  ///< End date year
+    emonth = -1,  ///< End date month
+    eday = -1,  ///< End date month
+    ehour = -1,  ///< End date hour
+    emin = -1;  ///< End date minute
 
-  double ssec, ///< Start date seconds
-    esec;  ///< End date seconds
+  double ssec = -1.0, ///< Start date seconds
+    esec = -1.0;  ///< End date seconds
     
   std::array<char, thdate_bufflen> dstr = {}; ///< String for given date.
 
@@ -128,7 +128,7 @@ class thdate {
    * Standard constructor.
    */
   
-  thdate();
+  thdate() = default;
   
   
   /**
