@@ -86,8 +86,13 @@ thdb3dfc * thdb3ddata::insert_face(int type) {
   }
   return face;
 }
-  
-thdb3dvx * thdb3ddata::insert_vertex(double vxx, double vxy, double vxz, void * dt) {
+
+thdb3dvx * thdb3ddata::insert_vertex(lxVec v, std::any dt) {
+  return this->insert_vertex(v.x, v.y, v.z, std::move(dt));
+}
+
+
+thdb3dvx * thdb3ddata::insert_vertex(double vxx, double vxy, double vxz, std::any dt) {
   thdb3dvx * vertex;
   vertex = &(*thdatabase3d.vertex_list.insert(thdatabase3d.vertex_list.end(),thdb3dvx()));
   vertex->id = this->nvertices;
@@ -95,7 +100,7 @@ thdb3dvx * thdb3ddata::insert_vertex(double vxx, double vxy, double vxz, void *
   vertex->y = vxy;
   vertex->z = vxz;
   this->limits.update(vxx, vxy, vxz);
-  vertex->data = dt;
+  vertex->data = std::move(dt);
   this->nvertices++;
   if (this->lastvx == NULL) {
     this->firstvx = vertex;
@@ -107,7 +112,7 @@ thdb3dvx * thdb3ddata::insert_vertex(double vxx, double vxy, double vxz, void *
   return vertex;
 }
 
-thdb3dfx * thdb3dfc::insert_vertex(thdb3dvx * vx, void * dt) {
+thdb3dfx * thdb3dfc::insert_vertex(thdb3dvx * vx, std::any dt) {
   thdb3dfx * fx;
   fx = &(*thdatabase3d.face_vertex_list.insert(thdatabase3d.face_vertex_list.end(),thdb3dfx()));
   this->nvx++;
@@ -119,7 +124,7 @@ thdb3dfx * thdb3dfc::insert_vertex(thdb3dvx * vx, void * dt) {
     this->lastfx = fx;
   }
   fx->vertex = vx;
-  fx->data = dt;
+  fx->data = std::move(dt);
   return fx;
 }
 
@@ -154,7 +159,7 @@ thdb3dnm * thdb3dvx::insert_normal(double nx, double ny, double nz) {
 void thdb3ddata::export_thm(FILE * out) {
   thdb3dfc * fc;
   thdb3dfx * fx;
-  char * typestr;
+  const char * typestr;
   for (fc = this->firstfc; fc != NULL; fc = fc->next) {
     switch (fc->type) {
       case THDB3DFC_LINES:
@@ -427,9 +432,9 @@ void thdb3ddata::postprocess() {
 
 
 
-void thdb3ddata::export_dxf(FILE * out, char * LAYER) {
+void thdb3ddata::export_dxf(FILE * out, const char * LAYER) {
   thdb3dfc * fc;
-  thdb3dfx * fx, * fx1, * fx2, * fx3;
+  thdb3dfx * fx, * fx1, * fx2 = NULL, * fx3 = NULL;
   bool reverse;  
   
   for (fc = this->firstfc; fc != NULL; fc = fc->next) {
@@ -498,85 +503,6 @@ void thdb3ddata::export_dxf(FILE * out, char * LAYER) {
   }
 }
 
-void thdb3ddata::export_tlx(FILE * out) {
-  thdb3dfc * fc;
-  thdb3dfx * fx, * fx1, * fx2, * fx3;
-  thdb3dvx * vx;
-  long id1;
-  id1 = 0;
-  for(vx = this->firstvx; vx != NULL; vx = vx->next)
-    fprintf(out,"P %ld %8.3f %8.3f %8.3f\n", id1++,
-      vx->x - this->exp_shift_x, 
-      vx->y - this->exp_shift_y, 
-      vx->z - this->exp_shift_z);
-
-  for (fc = this->firstfc; fc != NULL; fc = fc->next) {
-    switch (fc->type) {
-      case THDB3DFC_TRIANGLES:
-        fx = fc->firstfx;
-        while (fx != NULL) {
-          fx1 = fx; fx = fx->next; fx2 = NULL; fx3 = NULL;
-          if (fx != NULL) {
-            fx2 = fx; fx = fx->next;
-          }
-          if (fx != NULL) {
-            fx3 = fx; fx = fx->next;
-          }
-          if (fx3 != NULL) {
-            fprintf(out,"L 1 3 %6ld %6ld %6ld\n",
-              fx1->vertex->id,
-              fx2->vertex->id,
-              fx3->vertex->id);
-          }
-        }
-        break;      
-      case THDB3DFC_TRIANGLE_STRIP:
-        fx = fc->firstfx;
-        id1 = 0;
-        while (fx != NULL) {
-          id1++;
-          fx = fx->next;
-        }
-        if (id1 > 2) {
-          fprintf(out,"L 2 %ld", id1);
-          fx = fc->firstfx;
-          while (fx != NULL) {
-            fprintf(out," %ld", fx->vertex->id);
-            fx = fx->next;
-          }
-          fprintf(out,"\n");
-        }
-        break;      
-      case THDB3DFC_LINE_STRIP:
-        fx = fc->firstfx;
-        id1 = 0;
-        while (fx != NULL) {
-          id1++;
-          fx = fx->next;
-        }
-        if (id1 > 1) {
-          fprintf(out,"L 0 %ld", id1);
-          fx = fc->firstfx;
-          while (fx != NULL) {
-            fprintf(out," %ld", fx->vertex->id);
-            fx = fx->next;
-          }
-          fprintf(out,"\n");
-        }
-        break;      
-      case THDB3DFC_TRIANGLE_FAN:
-      case THDB3DFC_QUADS:
-      case THDB3DFC_QUAD_STRIP:
-      case THDB3DFC_POLYGON:
-      case THDB3DFC_LINES:
-      case THDB3DFC_LINE_LOOP:
-      default:
-        break;      
-    }
-  }
-}
-
-
 
 thdb3d thdatabase3d;
 
