@@ -32,7 +32,7 @@
 #include "thdata.h"
 #include "thsurvey.h"
 #include <stdio.h>
-#include "extern/img.h"
+#include "img.h"
 #include "thscrap.h"
 #include "thsurface.h"
 #include "loch/lxFile.h"
@@ -748,7 +748,7 @@ void thexpmodel::export_vrml_file(class thdatabase * dbp) {
     while (obi != dbp->object_list.end()) {
       switch ((*obi)->get_class_id()) {
         case TT_SURFACE_CMD:
-          srfc = ((thsurface*)(*obi).get());
+          srfc = dynamic_cast<thsurface*>(obi->get());
           tmp3d = srfc->get_3d();
           srfc->calibrate();
           tinv = srfc->calib_yy*srfc->calib_xx - srfc->calib_xy*srfc->calib_yx;
@@ -768,8 +768,8 @@ void thexpmodel::export_vrml_file(class thdatabase * dbp) {
                   fseek(xf.get(), 0, SEEK_SET);
                   if (fsz > 0) {
                     char * cdata = new char [fsz];
-                    thassert(fread((void *) cdata, 1, fsz, xf.get()) == fsz);
-                    fwrite((void *) cdata, 1, fsz, texf.get());
+                    thassert(fread(cdata, 1, fsz, xf.get()) == fsz);
+                    fwrite(cdata, 1, fsz, texf.get());
                     delete [] cdata;
                   }
                 }
@@ -1005,7 +1005,7 @@ void thexpmodel::export_3dmf_file(class thdatabase * dbp) {
     while (obi != dbp->object_list.end()) {
       switch ((*obi)->get_class_id()) {
         case TT_SURFACE_CMD:
-          tmp3d = ((thsurface*)(*obi).get())->get_3d();
+          tmp3d = dynamic_cast<thsurface*>(obi->get())->get_3d();
           if (tmp3d != NULL) {
             tmp3d->exp_shift_x = avx;
             tmp3d->exp_shift_y = avy;
@@ -1346,7 +1346,7 @@ void thexpmodel::export_dxf_file(class thdatabase * dbp) {
     while (obi != dbp->object_list.end()) {
       switch ((*obi)->get_class_id()) {
         case TT_SURFACE_CMD:
-          tmp3d = ((thsurface*)(*obi).get())->get_3d();
+          tmp3d = dynamic_cast<thsurface*>(obi->get())->get_3d();
           if (tmp3d != NULL) {
             tmp3d->exp_shift_x = avx;
             tmp3d->exp_shift_y = avy;
@@ -1483,7 +1483,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
   obi = dbp->object_list.begin();
   while (obi != dbp->object_list.end()) {
     if ((*obi)->get_class_id() == TT_SURVEY_CMD) {
-      sptr = (thsurvey*)(*obi).get();
+      sptr = dynamic_cast<thsurvey*>(obi->get());
       if (sptr->is_selected()) {
         sptr->num1 = 1;
       } else {
@@ -1527,7 +1527,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
   obi = dbp->object_list.begin();
   while (obi != dbp->object_list.end()) {
     if ((*obi)->get_class_id() == TT_SURVEY_CMD) {
-      sptr = (thsurvey*)(*obi).get();
+      sptr = dynamic_cast<thsurvey*>(obi->get());
       if ((sptr->num1 > 0) && (sptr->fsptr != NULL)) {
         tsptr = sptr->fsptr;
         if (tsptr->num1 > 0)
@@ -1554,7 +1554,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
   obi = dbp->object_list.begin();
   while (obi != dbp->object_list.end()) {
     if ((*obi)->get_class_id() == TT_SURVEY_CMD) {
-      sptr = (thsurvey*)(*obi).get();
+      sptr = dynamic_cast<thsurvey*>(obi->get());
       if (sptr->num1 > 0) {
         sptr->num1 = survnum++;
         expf_survey.m_id = sptr->num1;
@@ -1650,7 +1650,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
     while (obi != dbp->object_list.end()) {
       switch ((*obi)->get_class_id()) {
         case TT_SURFACE_CMD:
-          csrf = ((thsurface*)(*obi).get());
+          csrf = dynamic_cast<thsurface*>(obi->get());
           tmp3d = csrf->get_3d();
           if ((tmp3d != NULL) && (tmp3d->nfaces > 0)) {
             expf_sfc.m_id = survnum;
@@ -1667,7 +1667,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
             for(i = 0; i < (unsigned long) csrf->grid_size; i++) {
               cdata[i] = csrf->grid[i];
             }
-            expf_sfc.m_dataPtr = expf.m_surfacesData.AppendData((void *) cdata, csrf->grid_size * sizeof(lxFileDbl));
+            expf_sfc.m_dataPtr = expf.m_surfacesData.AppendData(reinterpret_cast<const uint8_t*>(cdata), csrf->grid_size * sizeof(lxFileDbl));
             expf.m_surfaces.push_back(expf_sfc);
             delete [] cdata;
             
@@ -1729,7 +1729,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
               pdata[i].m_c[2] = lxFilePrepDbl(vxp->z);
             }
             expf_scrap.m_numPoints = d3d->nvertices;
-            expf_scrap.m_pointsPtr = expf.m_scrapsData.AppendData(pdata, i * sizeof(lxFile3Point));
+            expf_scrap.m_pointsPtr = expf.m_scrapsData.AppendData(reinterpret_cast<const uint8_t*>(pdata), i * sizeof(lxFile3Point));
             thdb3dfc * fcp;
             thdb3dfx * fxp;
             for(i = 0, fcp = d3d->firstfc; fcp != NULL; fcp = fcp->next, i++) {
@@ -1765,7 +1765,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
               tdata[i] = *tli;
             }
             expf_scrap.m_num3Angles = tlist.size();
-            expf_scrap.m_3AnglesPtr = expf.m_scrapsData.AppendData(tdata, i * sizeof(lxFile3Angle));
+            expf_scrap.m_3AnglesPtr = expf.m_scrapsData.AppendData(reinterpret_cast<const uint8_t*>(tdata), i * sizeof(lxFile3Angle));
             delete [] pdata;
             delete [] tdata;
             expf.m_scraps.push_back(expf_scrap);
@@ -1801,7 +1801,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
             pdata[i].m_c[2] = lxFilePrepDbl(vxp->z);
           }
           expf_scrap.m_numPoints = d3d->nvertices;
-          expf_scrap.m_pointsPtr = expf.m_scrapsData.AppendData(pdata, i * sizeof(lxFile3Point));
+          expf_scrap.m_pointsPtr = expf.m_scrapsData.AppendData(reinterpret_cast<const uint8_t*>(pdata), i * sizeof(lxFile3Point));
           thdb3dfc * fcp;
           thdb3dfx * fxp;
           for(i = 0, fcp = d3d->firstfc; fcp != NULL; fcp = fcp->next, i++) {
@@ -1837,7 +1837,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
             tdata[i] = *tli;
           }
           expf_scrap.m_num3Angles = tlist.size();
-          expf_scrap.m_3AnglesPtr = expf.m_scrapsData.AppendData(tdata, i * sizeof(lxFile3Angle));
+          expf_scrap.m_3AnglesPtr = expf.m_scrapsData.AppendData(reinterpret_cast<const uint8_t*>(tdata), i * sizeof(lxFile3Angle));
           delete [] pdata;
           delete [] tdata;
           expf.m_scraps.push_back(expf_scrap);
@@ -1904,7 +1904,7 @@ void thexpmodel::export_kml_file(class thdatabase * dbp)
   thdataobject * obj;
   for(obj = mainsrv->foptr; obj != NULL; obj = obj->nsptr) 
     if (obj->get_class_id() == TT_SURVEY_CMD) {
-      mainsrv = (thsurvey *) obj;
+      mainsrv = dynamic_cast<thsurvey*>(obj);
       break;
     }
 
@@ -2007,7 +2007,7 @@ void thexpmodel::export_kml_survey_file(FILE * out, thsurvey * surv)
   for(obj = surv->foptr; obj != NULL; obj = obj->nsptr) {
     switch (obj->get_class_id()) {
       case TT_SURVEY_CMD: {
-        thsurvey * subsurv = (thsurvey *) obj;
+        thsurvey * subsurv = dynamic_cast<thsurvey*>(obj);
 
         if ((strlen(subsurv->name) == 0) || !(subsurv->is_selected()))
           break;
@@ -2024,7 +2024,7 @@ void thexpmodel::export_kml_survey_file(FILE * out, thsurvey * surv)
         double x, y, z;
         bool first_station = true;
         thdataleg_list::iterator legs;
-        thdata * survdata = (thdata *) obj;
+        thdata * survdata = dynamic_cast<thdata*>(obj);
 
         if (survdata->leg_list.empty())  // skip empty data blocks
           break;
