@@ -31,7 +31,7 @@
 #include "thdata.h"
 #include "thsurvey.h"
 #include "thdatabase.h"
-#include "extern/img.h"
+#include "img.h"
 #include <string.h>
 #include <string>
 #include <map>
@@ -42,7 +42,7 @@
 
 struct thsst {
   std::string name, fullname;
-  thsurvey * survey;  
+  thsurvey * survey = {};  
 };
 
 
@@ -365,12 +365,12 @@ const char * thimport::station_name(const char * sn, const char separator, struc
 }
 
 struct thimg_shot {
-  double fx, fy, fz, tx, ty, tz;
-  long flags;
+  double fx = {}, fy = {}, fz = {}, tx = {}, ty = {}, tz = {};
+  long flags = {};
 };
 
 struct thimg_stpos {
-  double x, y, z;
+  double x = {}, y = {}, z = {};
 };
 
 bool operator < (const thimg_stpos & p1, 
